@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2009 The PHP Group                                |
+   | Copyright (c) 1997-2010 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: unixtime2tm.c,v 1.12.2.4.2.6 2008/12/31 11:17:36 sebastian Exp $ */
+/* $Id: unixtime2tm.c 319767 2011-11-24 17:13:47Z derick $ */
 
 #include "timelib.h"
 
@@ -51,10 +51,16 @@ void timelib_unixtime2gmt(timelib_time* tm, timelib_sll ts)
 		days++;
 		remainder -= SECS_PER_DAY;
 	}
-	DEBUG(printf("days=%lld, rem=%lld\n", days, remainder););
+	TIMELIB_DEBUG(printf("days=%lld, rem=%lld\n", days, remainder););
 
 	if (ts >= 0) {
 		tmp_days = days + 1;
+
+		if (tmp_days >= DAYS_PER_LYEAR_PERIOD || tmp_days <= -DAYS_PER_LYEAR_PERIOD) {
+			cur_year += YEARS_PER_LYEAR_PERIOD * (tmp_days / DAYS_PER_LYEAR_PERIOD);
+			tmp_days -= DAYS_PER_LYEAR_PERIOD * (tmp_days / DAYS_PER_LYEAR_PERIOD);
+		}
+
 		while (tmp_days >= DAYS_PER_LYEAR) {
 			cur_year++;
 			if (timelib_is_leap(cur_year)) {
@@ -78,11 +84,11 @@ void timelib_unixtime2gmt(timelib_time* tm, timelib_sll ts)
 		while (tmp_days <= 0) {
 			if (tmp_days < -1460970) {
 				cur_year -= 4000;
-				DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
+				TIMELIB_DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
 				tmp_days += 1460970;
 			} else {
 				cur_year--;
-				DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
+				TIMELIB_DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
 				if (timelib_is_leap(cur_year)) {
 					tmp_days += DAYS_PER_LYEAR;
 				} else {
@@ -92,7 +98,7 @@ void timelib_unixtime2gmt(timelib_time* tm, timelib_sll ts)
 		}
 		remainder += SECS_PER_DAY;
 	}
-	DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
+	TIMELIB_DEBUG(printf("tmp_days=%lld, year=%lld\n", tmp_days, cur_year););
 
 	months = timelib_is_leap(cur_year) ? month_tab_leap : month_tab;
 	if (timelib_is_leap(cur_year) && cur_year < 1970) {
@@ -100,19 +106,19 @@ void timelib_unixtime2gmt(timelib_time* tm, timelib_sll ts)
 	}
 	i = 11;
 	while (i > 0) {
-		DEBUG(printf("month=%lld (%d)\n", i, months[i]););
+		TIMELIB_DEBUG(printf("month=%lld (%d)\n", i, months[i]););
 		if (tmp_days > months[i]) {
 			break;
 		}
 		i--;
 	}
-	DEBUG(printf("A: ts=%lld, year=%lld, month=%lld, day=%lld,", ts, cur_year, i + 1, tmp_days - months[i]););
+	TIMELIB_DEBUG(printf("A: ts=%lld, year=%lld, month=%lld, day=%lld,", ts, cur_year, i + 1, tmp_days - months[i]););
 
 	/* That was the date, now we do the tiiiime */
 	hours = remainder / 3600;
 	minutes = (remainder - hours * 3600) / 60;
 	seconds = remainder % 60;
-	DEBUG(printf(" hour=%lld, minute=%lld, second=%lld\n", hours, minutes, seconds););
+	TIMELIB_DEBUG(printf(" hour=%lld, minute=%lld, second=%lld\n", hours, minutes, seconds););
 
 	tm->y = cur_year;
 	tm->m = i + 1;
@@ -140,7 +146,7 @@ void timelib_update_from_sse(timelib_time *tm)
 			int z = tm->z;
 			signed int dst = tm->dst;
 			
-			timelib_unixtime2gmt(tm, tm->sse - (tm->z * 60));
+			timelib_unixtime2gmt(tm, tm->sse - (tm->z * 60) + (tm->dst * 3600));
 
 			tm->z = z;
 			tm->dst = dst;
@@ -178,7 +184,7 @@ void timelib_unixtime2local(timelib_time *tm, timelib_sll ts)
 			int z = tm->z;
 			signed int dst = tm->dst;
 			
-			timelib_unixtime2gmt(tm, ts - (tm->z * 60));
+			timelib_unixtime2gmt(tm, ts - (tm->z * 60) + (tm->dst * 3600));
 
 			tm->z = z;
 			tm->dst = dst;
@@ -240,18 +246,18 @@ int timelib_apply_localtime(timelib_time *t, unsigned int localtime)
 {
 	if (localtime) {
 		/* Converting from GMT time to local time */
-		DEBUG(printf("Converting from GMT time to local time\n"););
+		TIMELIB_DEBUG(printf("Converting from GMT time to local time\n"););
 
 		/* Check if TZ is set */
 		if (!t->tz_info) {
-			DEBUG(printf("E: No timezone configured, can't switch to local time\n"););
+			TIMELIB_DEBUG(printf("E: No timezone configured, can't switch to local time\n"););
 			return -1;
 		}
 
 		timelib_unixtime2local(t, t->sse);
 	} else {
 		/* Converting from local time to GMT time */
-		DEBUG(printf("Converting from local time to GMT time\n"););
+		TIMELIB_DEBUG(printf("Converting from local time to GMT time\n"););
 
 		timelib_unixtime2gmt(t, t->sse);
 	}
