@@ -29,17 +29,15 @@
  * print.c - debugging printout routines
  */
 
-#define _GNU_SOURCE
 #include "php.h"
+#include "main/snprintf.h"
 
 #include "file.h"
-#include "cdf.h"
 
 #ifndef lint
-FILE_RCSID("@(#)$File: print.c,v 1.76 2013/02/26 18:25:00 christos Exp $")
+FILE_RCSID("@(#)$File: print.c,v 1.66 2009/02/03 20:27:51 christos Exp $")
 #endif  /* lint */
 
-#include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -48,11 +46,6 @@ FILE_RCSID("@(#)$File: print.c,v 1.76 2013/02/26 18:25:00 christos Exp $")
 #endif
 #include <time.h>
 
-#ifdef PHP_WIN32
-# define asctime_r php_asctime_r
-# define ctime_r php_ctime_r
-#endif
-
 #define SZOF(a)	(sizeof(a) / sizeof(a[0]))
 
 /*VARARGS*/
@@ -64,7 +57,7 @@ file_magwarn(struct magic_set *ms, const char *f, ...)
 	TSRMLS_FETCH();
 
 	va_start(va, f);
-	if (vasprintf(&expanded_format, f, va)); /* silence */
+	vasprintf(&expanded_format, f, va);
 	va_end(va);
 	
 	php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Warning: %s", expanded_format);
@@ -73,20 +66,14 @@ file_magwarn(struct magic_set *ms, const char *f, ...)
 }
 
 protected const char *
-file_fmttime(uint64_t v, int flags, char *buf)
+file_fmttime(uint32_t v, int local)
 {
 	char *pp;
 	time_t t = (time_t)v;
 	struct tm *tm;
 
-	if (flags & FILE_T_WINDOWS) {
-		struct timeval ts;
-		cdf_timestamp_to_timespec(&ts, t);
-		t = ts.tv_sec;
-	}
-
-	if (flags & FILE_T_LOCAL) {
-		pp = ctime_r(&t, buf);
+	if (local) {
+		pp = ctime(&t);
 	} else {
 #ifndef HAVE_DAYLIGHT
 		private int daylight = 0;
@@ -98,7 +85,7 @@ file_fmttime(uint64_t v, int flags, char *buf)
 			(void)time(&now);
 			tm1 = localtime(&now);
 			if (tm1 == NULL)
-				goto out;
+				return "*Invalid time*";
 			daylight = tm1->tm_isdst;
 		}
 #endif /* HAVE_TM_ISDST */
@@ -107,14 +94,10 @@ file_fmttime(uint64_t v, int flags, char *buf)
 			t += 3600;
 		tm = gmtime(&t);
 		if (tm == NULL)
-			goto out;
-		pp = asctime_r(tm, buf);
+			return "*Invalid time*";
+		pp = asctime(tm);
 	}
 
-	if (pp == NULL)
-		goto out;
 	pp[strcspn(pp, "\n")] = '\0';
 	return pp;
-out:
-	return strcpy(buf, "*Invalid time*");
 }
