@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2007 The PHP Group                                |
+   | Copyright (c) 1997-2012 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_ftp.c,v 1.103.2.2.2.2 2007/01/01 09:36:01 sebastian Exp $ */
+/* $Id: php_ftp.c 321634 2012-01-01 13:15:04Z felipe $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -45,7 +45,6 @@ static int	le_ftpbuf;
 #define le_ftpbuf_name "FTP Buffer"
 
 /* {{{ arginfo */
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_connect, 0, 0, 1)
 	ZEND_ARG_INFO(0, host)
 	ZEND_ARG_INFO(0, port)
@@ -53,7 +52,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_connect, 0, 0, 1)
 ZEND_END_ARG_INFO()
 
 #if HAVE_OPENSSL_EXT
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_ssl_connect, 0, 0, 1)
 	ZEND_ARG_INFO(0, host)
 	ZEND_ARG_INFO(0, port)
@@ -61,86 +59,72 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_ssl_connect, 0, 0, 1)
 ZEND_END_ARG_INFO()
 #endif
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_login, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, username)
 	ZEND_ARG_INFO(0, password)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_pwd, 0)
 	ZEND_ARG_INFO(0, ftp)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_cdup, 0)
 	ZEND_ARG_INFO(0, ftp)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_chdir, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, directory)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_exec, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, command)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_raw, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, command)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_mkdir, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, directory)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_rmdir, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, directory)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_chmod, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, mode)
 	ZEND_ARG_INFO(0, filename)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_alloc, 0, 0, 2)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, size)
 	ZEND_ARG_INFO(1, response)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_nlist, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, directory)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_rawlist, 0, 0, 2)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, directory)
 	ZEND_ARG_INFO(0, recursive)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_systype, 0)
 	ZEND_ARG_INFO(0, ftp)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_fget, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, fp)
@@ -149,7 +133,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_fget, 0, 0, 4)
 	ZEND_ARG_INFO(0, resumepos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_fget, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, fp)
@@ -158,13 +141,11 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_fget, 0, 0, 4)
 	ZEND_ARG_INFO(0, resumepos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_pasv, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, pasv)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_get, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, local_file)
@@ -173,7 +154,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_get, 0, 0, 4)
 	ZEND_ARG_INFO(0, resume_pos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_get, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, local_file)
@@ -182,12 +162,10 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_get, 0, 0, 4)
 	ZEND_ARG_INFO(0, resume_pos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_nb_continue, 0)
 	ZEND_ARG_INFO(0, ftp)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_fput, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, remote_file)
@@ -196,7 +174,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_fput, 0, 0, 4)
 	ZEND_ARG_INFO(0, startpos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_fput, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, remote_file)
@@ -205,7 +182,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_fput, 0, 0, 4)
 	ZEND_ARG_INFO(0, startpos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_put, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, remote_file)
@@ -214,7 +190,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_put, 0, 0, 4)
 	ZEND_ARG_INFO(0, startpos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_put, 0, 0, 4)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, remote_file)
@@ -223,50 +198,42 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_ftp_nb_put, 0, 0, 4)
 	ZEND_ARG_INFO(0, startpos)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_size, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, filename)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_mdtm, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, filename)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_rename, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, src)
 	ZEND_ARG_INFO(0, dest)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_delete, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, file)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_site, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, cmd)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_close, 0)
 	ZEND_ARG_INFO(0, ftp)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_set_option, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, option)
 	ZEND_ARG_INFO(0, value)
 ZEND_END_ARG_INFO()
 
-static
 ZEND_BEGIN_ARG_INFO(arginfo_ftp_get_option, 0)
 	ZEND_ARG_INFO(0, ftp)
 	ZEND_ARG_INFO(0, option)
@@ -274,7 +241,7 @@ ZEND_END_ARG_INFO()
 
 /* }}} */
 
-zend_function_entry php_ftp_functions[] = {
+const zend_function_entry php_ftp_functions[] = {
 	PHP_FE(ftp_connect,			arginfo_ftp_connect)
 #if HAVE_OPENSSL_EXT
 	PHP_FE(ftp_ssl_connect,		arginfo_ftp_ssl_connect)
@@ -311,7 +278,7 @@ zend_function_entry php_ftp_functions[] = {
 	PHP_FE(ftp_nb_put,			arginfo_ftp_nb_put)
 	PHP_FE(ftp_nb_fput,			arginfo_ftp_nb_fput)
 	PHP_FALIAS(ftp_quit, ftp_close, arginfo_ftp_close)
-	{NULL, NULL, NULL}
+	PHP_FE_END
 };
 
 zend_module_entry php_ftp_module_entry = {
