@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2007 The PHP Group                                |
+   | Copyright (c) 1997-2012 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: safe_mode.c,v 1.62.2.1.2.9 2007/07/21 01:43:33 jani Exp $ */
+/* $Id: safe_mode.c 321634 2012-01-01 13:15:04Z felipe $ */
 
 #include "php.h"
 
@@ -52,7 +52,6 @@ PHPAPI int php_checkuid_ex(const char *filename, const char *fopen_mode, int mod
 	long uid=0L, gid=0L, duid=0L, dgid=0L;
 	char path[MAXPATHLEN];
 	char *s, filenamecopy[MAXPATHLEN];
-	php_stream_wrapper *wrapper = NULL;
 	TSRMLS_FETCH();
 
 	path[0] = '\0';
@@ -73,20 +72,21 @@ PHPAPI int php_checkuid_ex(const char *filename, const char *fopen_mode, int mod
 			mode = CHECKUID_CHECK_FILE_AND_DIR;
 		}
 	}
-
-	/* 
-	 * If given filepath is a URL, allow - safe mode stuff
-	 * related to URL's is checked in individual functions
-	 */
-	wrapper = php_stream_locate_url_wrapper(filename, NULL, STREAM_LOCATE_WRAPPERS_ONLY TSRMLS_CC);
-	if (wrapper != NULL)
-		return 1;
 		
 	/* First we see if the file is owned by the same user...
 	 * If that fails, passthrough and check directory...
 	 */
 	if (mode != CHECKUID_ALLOW_ONLY_DIR) {
+#if HAVE_BROKEN_GETCWD
+		char ftest[MAXPATHLEN];
+
+		strcpy(ftest, filename);
+		if (VCWD_GETCWD(ftest, sizeof(ftest)) == NULL) {
+			strcpy(path, filename);
+		} else
+#endif
 		expand_filepath(filename, path TSRMLS_CC);
+
 		ret = VCWD_STAT(path, &sb);
 		if (ret < 0) {
 			if (mode == CHECKUID_DISALLOW_FILE_NOT_EXISTS) {
@@ -113,10 +113,17 @@ PHPAPI int php_checkuid_ex(const char *filename, const char *fopen_mode, int mod
 
 		/* Trim off filename */
 		if ((s = strrchr(path, DEFAULT_SLASH))) {
-			if (s == path)
-				path[1] = '\0';
-			else
+			if (*(s + 1) == '\0' && s != path) { /* make sure that the / is not the last character */
 				*s = '\0';
+				s = strrchr(path, DEFAULT_SLASH);
+			}
+			if (s) {
+				if (s == path) {
+					path[1] = '\0';
+				} else {
+					*s = '\0';
+				}
+			}
 		}
 	} else { /* CHECKUID_ALLOW_ONLY_DIR */
 		s = strrchr(filename, DEFAULT_SLASH);
@@ -125,7 +132,7 @@ PHPAPI int php_checkuid_ex(const char *filename, const char *fopen_mode, int mod
 			/* root dir */
 			path[0] = DEFAULT_SLASH;
 			path[1] = '\0';
-		} else if (s) {
+		} else if (s && *(s + 1) != '\0') { /* make sure that the / is not the last character */
 			*s = '\0';
 			VCWD_REALPATH(filename, path);
 			*s = DEFAULT_SLASH;
