@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2008 The PHP Group                                |
+   | Copyright (c) 1997-2012 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_stream_context.h,v 1.11.2.1.2.2 2007/12/31 07:20:15 sebastian Exp $ */
+/* $Id: php_stream_context.h 321634 2012-01-01 13:15:04Z felipe $ */
 
 /* Stream context and status notification related definitions */
 
@@ -31,7 +31,7 @@ typedef void (*php_stream_notification_func)(php_stream_context *context,
 
 /* Attempt to fetch context from the zval passed,
    If no context was passed, use the default context
-   The the default context has not yet been created, do it now. */
+   The default context has not yet been created, do it now. */
 #define php_stream_context_from_zval(zcontext, nocontext) ( \
 		(zcontext) ? zend_fetch_resource(&(zcontext) TSRMLS_CC, -1, "Stream-Context", NULL, 1, php_le_stream_context()) : \
 		(nocontext) ? NULL : \
